#include <sourcemod>
#include <cstrike>
#include <autoexecconfig>
#include <sdktools_stringtables>

#define DEBUG

#pragma semicolon 1

#pragma newdecls required

public Plugin myinfo = 
{
	name = "Team Logo", 
	author = "Lantejoula", 
	description = "Team Logo (Compatible with Half Time)", 
	version = "1.2", 
	url = "https://steamcommunity.com/id/lantejoula"
}

//HANDLE

Handle g_TeamLogoT = INVALID_HANDLE;
Handle g_TeamLogoCT = INVALID_HANDLE;

Handle g_TeamLogo1 = INVALID_HANDLE;
Handle g_TeamLogo2 = INVALID_HANDLE;

//CONVAR

ConVar g_RestartGame;

//CHARS

char TeamLogoCT[256];
char TeamLogoT[256];

//BOOL

bool RestartGame1 = false;

public void OnPluginStart()
{
	AutoExecConfig_SetFile("plugin.teamlogo");
	
	g_TeamLogoCT = AutoExecConfig_CreateConVar("sm_teamlogo_ct", "logoct", "Counter-Terrorist Logo File Name (materials/panorama/images/tournaments/teams) [Format: .svg]");
	g_TeamLogoT = AutoExecConfig_CreateConVar("sm_teamlogo_t", "logot", "Terrorist Logo File Name (materials/panorama/images/tournaments/teams) [Format: .svg]");
	
	AutoExecConfig_ExecuteFile();
	AutoExecConfig_CleanFile();
	
	g_TeamLogo1 = FindConVar("mp_teamlogo_1");
	g_TeamLogo2 = FindConVar("mp_teamlogo_2");
	
	g_RestartGame = FindConVar("mp_restartgame");
	
	HookConVarChange(g_TeamLogoT, OnChange);
	HookConVarChange(g_TeamLogoCT, OnChange);
	
	HookConVarChange(g_RestartGame, OnChangeRestartGame);
	
	//EVENT
	
	HookEvent("round_start", Event_RoundStart, EventHookMode_PostNoCopy);
}

//LOGO

public void Logo()
{
	//T
	
	char TLOGO[128];
	
	Format(TLOGO, sizeof(TLOGO), "materials/panorama/images/tournaments/teams/%s.svg", TeamLogoT);
	if (FileExists(TLOGO))
	{
		PrecacheDecal(TLOGO, true);
		AddFileToDownloadsTable(TLOGO);
		
		LogMessage("Precaching and Downloading: %s", TLOGO);
	}
	else
	{
		LogError("File does not exist: %s", TLOGO);
	}
	
	//CT
	
	char CTLOGO[128];
	
	Format(CTLOGO, sizeof(CTLOGO), "materials/panorama/images/tournaments/teams/%s.svg", TeamLogoCT);
	if (FileExists(CTLOGO))
	{
		PrecacheDecal(CTLOGO, true);
		AddFileToDownloadsTable(CTLOGO);
		
		LogMessage("Precaching and Downloading: %s", CTLOGO);
	}
	else
	{
		LogError("File does not exist: %s", CTLOGO);
	}
}

//MAP START

public void OnMapStart()
{
	RestartGame1 = false;
}

//CONVARS

public void Refresh()
{
	GetConVarString(g_TeamLogoCT, TeamLogoCT, sizeof(TeamLogoCT));
	SetConVarString(g_TeamLogo1, TeamLogoCT);
	
	GetConVarString(g_TeamLogoT, TeamLogoT, sizeof(TeamLogoT));
	SetConVarString(g_TeamLogo2, TeamLogoT);
}

//REFRESH

public void OnConfigsExecuted()
{
	Refresh();
	
	Logo();
}

public void OnChange(Handle cvar, char[] oldvalue, char[] newvalue)
{
	Refresh();
}

//RESTART GAME 

public void OnChangeRestartGame(Handle cvar, char[] oldvalue, char[] newvalue)
{
	RestartGame1 = true;
}

//ROUND START

public void Event_RoundStart(Event event, const char[] name, bool dontBroadcast)
{
	int maxrounds = GetConVarInt(FindConVar("mp_maxrounds"));
	
	int timeleft, timelimit;
	
	GetMapTimeLeft(timeleft);
	GetMapTimeLimit(timelimit);
	
	if ((maxrounds != 0 && (CS_GetTeamScore(2) + CS_GetTeamScore(3)) == (maxrounds / 2)) || (timelimit != 0 && timeleft <= (timelimit * 60 / 2)))
	{
		GetConVarString(g_TeamLogoCT, TeamLogoCT, sizeof(TeamLogoCT));
		SetConVarString(g_TeamLogo2, TeamLogoCT);
		
		GetConVarString(g_TeamLogoT, TeamLogoT, sizeof(TeamLogoT));
		SetConVarString(g_TeamLogo1, TeamLogoT);
	}
	
	if (RestartGame1)
	{
		Refresh();
		
		RestartGame1 = false;
	}
} 